Struct CancelOrderByOid
pub struct CancelOrderByOid {
pub asset: u32,
pub oid: u64,
}Expand description
struct CancelOrderByOid { uint32 asset; uint64 oid; }Fields
asset: u32oid: u64Trait Implementations
impl Clone for CancelOrderByOid
impl Clone for CancelOrderByOid
fn clone(&self) -> CancelOrderByOid
fn clone(&self) -> CancelOrderByOid
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for CancelOrderByOid
impl Debug for CancelOrderByOid
impl EventTopic for CancelOrderByOid
impl EventTopic for CancelOrderByOid
fn topic_preimage_length(
rust: &<CancelOrderByOid as SolType>::RustType,
) -> usize
fn topic_preimage_length( rust: &<CancelOrderByOid as SolType>::RustType, ) -> usize
The number of bytes this type occupies in another topic’s preimage,
usually a multiple of 32. Read more
fn encode_topic_preimage(
rust: &<CancelOrderByOid as SolType>::RustType,
out: &mut Vec<u8>,
)
fn encode_topic_preimage( rust: &<CancelOrderByOid as SolType>::RustType, out: &mut Vec<u8>, )
Encodes this type as preimage bytes which are then hashed in
complex types’ [
encode_topic][EventTopic::encode_topic]. Read morefn encode_topic(rust: &<CancelOrderByOid as SolType>::RustType) -> WordToken
fn encode_topic(rust: &<CancelOrderByOid as SolType>::RustType) -> WordToken
Indexed event parameter encoding. Read more
impl PartialEq for CancelOrderByOid
impl PartialEq for CancelOrderByOid
impl SolStruct for CancelOrderByOid
impl SolStruct for CancelOrderByOid
fn eip712_root_type() -> Cow<'static, str>
fn eip712_root_type() -> Cow<'static, str>
Return the root EIP-712 type. This type is used to construct the
encodeType string.fn eip712_components() -> Vec<Cow<'static, str>>
fn eip712_components() -> Vec<Cow<'static, str>>
Returns component EIP-712 types. These types are used to construct
the
encodeType string. These are the types of the struct’s fields,
and should not include the root type.fn eip712_encode_type() -> Cow<'static, str>
fn eip712_encode_type() -> Cow<'static, str>
The EIP-712-encoded type string. Read more
fn eip712_encode_data(&self) -> Vec<u8> ⓘ
fn eip712_encode_data(&self) -> Vec<u8> ⓘ
Encodes this domain using EIP-712
encodeData.fn eip712_type_hash(&self) -> FixedBytes<32>
fn eip712_type_hash(&self) -> FixedBytes<32>
Calculates the EIP-712
typeHash
for this struct. Read morefn eip712_hash_struct(&self) -> FixedBytes<32>
fn eip712_hash_struct(&self) -> FixedBytes<32>
Calculates the EIP-712
hashStruct for this value.fn eip712_signing_hash(&self, domain: &Eip712Domain) -> FixedBytes<32>
fn eip712_signing_hash(&self, domain: &Eip712Domain) -> FixedBytes<32>
Calculate the EIP-712 signing hash
for this struct.
Note that this does not sign the hash, only calculates it. Read more
impl SolType for CancelOrderByOid
impl SolType for CancelOrderByOid
const SOL_NAME: &'static str = <Self as alloy_sol_types::SolStruct>::NAME
const SOL_NAME: &'static str = <Self as alloy_sol_types::SolStruct>::NAME
The name of this type in Solidity.
const ENCODED_SIZE: Option<usize> = <UnderlyingSolTuple as alloy_sol_types::SolType>::ENCODED_SIZE
const ENCODED_SIZE: Option<usize> = <UnderlyingSolTuple as alloy_sol_types::SolType>::ENCODED_SIZE
The statically-known ABI-encoded size of the type. Read more
const PACKED_ENCODED_SIZE: Option<usize> = <UnderlyingSolTuple as alloy_sol_types::SolType>::PACKED_ENCODED_SIZE
const PACKED_ENCODED_SIZE: Option<usize> = <UnderlyingSolTuple as alloy_sol_types::SolType>::PACKED_ENCODED_SIZE
The statically-known Non-standard Packed Mode ABI-encoded size of the type. Read more
type RustType = CancelOrderByOid
type RustType = CancelOrderByOid
The corresponding Rust type.
type Token<'a> = <(Uint<32>, Uint<64>) as SolType>::Token<'a>
type Token<'a> = <(Uint<32>, Uint<64>) as SolType>::Token<'a>
The corresponding ABI token type. Read more
fn valid_token(token: &<CancelOrderByOid as SolType>::Token<'_>) -> bool
fn valid_token(token: &<CancelOrderByOid as SolType>::Token<'_>) -> bool
Returns
true if the given token can be detokenized with this type.fn detokenize(
token: <CancelOrderByOid as SolType>::Token<'_>,
) -> <CancelOrderByOid as SolType>::RustType
fn detokenize( token: <CancelOrderByOid as SolType>::Token<'_>, ) -> <CancelOrderByOid as SolType>::RustType
Detokenize this type’s value from the given token. Read more
fn abi_encoded_size<E>(rust: &E) -> usizewhere
E: SolTypeValue<Self> + ?Sized,
fn abi_encoded_size<E>(rust: &E) -> usizewhere
E: SolTypeValue<Self> + ?Sized,
Calculate the ABI-encoded size of the data, counting both head and tail
words. For a single-word type this will always be 32.
fn type_check(token: &Self::Token<'_>) -> Result<(), Error>
fn type_check(token: &Self::Token<'_>) -> Result<(), Error>
Returns an error if the given token cannot be detokenized with this
type.
fn tokenize<E>(rust: &E) -> Self::Token<'_>where
E: SolTypeValue<Self> + ?Sized,
fn tokenize<E>(rust: &E) -> Self::Token<'_>where
E: SolTypeValue<Self> + ?Sized,
Tokenizes the given value into this type’s token. Read more
fn eip712_data_word<E>(rust: &E) -> FixedBytes<32>where
E: SolTypeValue<Self> + ?Sized,
fn eip712_data_word<E>(rust: &E) -> FixedBytes<32>where
E: SolTypeValue<Self> + ?Sized,
Encode this data according to EIP-712
encodeData rules, and hash it
if necessary. Read morefn abi_packed_encoded_size<E>(rust: &E) -> usizewhere
E: SolTypeValue<Self> + ?Sized,
fn abi_packed_encoded_size<E>(rust: &E) -> usizewhere
E: SolTypeValue<Self> + ?Sized,
Returns the length of this value when ABI-encoded in Non-standard Packed Mode. Read more
fn abi_encode_packed_to<E>(rust: &E, out: &mut Vec<u8>)where
E: SolTypeValue<Self> + ?Sized,
fn abi_encode_packed_to<E>(rust: &E, out: &mut Vec<u8>)where
E: SolTypeValue<Self> + ?Sized,
Non-standard Packed Mode ABI encoding. Read more
fn abi_encode_packed<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
fn abi_encode_packed<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
Non-standard Packed Mode ABI encoding. Read more
fn abi_encode<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
fn abi_encode<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
Tokenizes and ABI-encodes the given value by wrapping it in a
single-element sequence. Read more
fn abi_encode_params<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
Self::Token<'a>: for<'a> TokenSeq<'a>,
fn abi_encode_params<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
Self::Token<'a>: for<'a> TokenSeq<'a>,
Tokenizes and ABI-encodes the given value as function parameters. Read more
fn abi_encode_sequence<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
Self::Token<'a>: for<'a> TokenSeq<'a>,
fn abi_encode_sequence<E>(rust: &E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self> + ?Sized,
Self::Token<'a>: for<'a> TokenSeq<'a>,
Tokenizes and ABI-encodes the given value as a sequence. Read more
fn abi_decode(data: &[u8]) -> Result<Self::RustType, Error>
fn abi_decode(data: &[u8]) -> Result<Self::RustType, Error>
Decodes this type’s value from an ABI blob by interpreting it as a
single-element sequence. Read more
fn abi_decode_validate(data: &[u8]) -> Result<Self::RustType, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self::RustType, Error>
Decodes this type’s value from an ABI blob by interpreting it as
single-element sequence, with validation. Read more
fn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self::RustType, Error>where
Self::Token<'de>: TokenSeq<'de>,
fn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self::RustType, Error>where
Self::Token<'de>: TokenSeq<'de>,
Decodes this type’s value from an ABI blob by interpreting it as
function parameters. Read more
fn abi_decode_params_validate<'de>(
data: &'de [u8],
) -> Result<Self::RustType, Error>where
Self::Token<'de>: TokenSeq<'de>,
fn abi_decode_params_validate<'de>(
data: &'de [u8],
) -> Result<Self::RustType, Error>where
Self::Token<'de>: TokenSeq<'de>,
Decodes this type’s value from an ABI blob by interpreting it as
function parameters, with validation. Read more
fn abi_decode_sequence<'de>(data: &'de [u8]) -> Result<Self::RustType, Error>where
Self::Token<'de>: TokenSeq<'de>,
fn abi_decode_sequence<'de>(data: &'de [u8]) -> Result<Self::RustType, Error>where
Self::Token<'de>: TokenSeq<'de>,
Decodes this type’s value from an ABI blob by interpreting it as a
sequence. Read more
fn abi_decode_sequence_validate<'de>(
data: &'de [u8],
) -> Result<Self::RustType, Error>where
Self::Token<'de>: TokenSeq<'de>,
fn abi_decode_sequence_validate<'de>(
data: &'de [u8],
) -> Result<Self::RustType, Error>where
Self::Token<'de>: TokenSeq<'de>,
Decodes this type’s value from an ABI blob by interpreting it as
sequence, with validation. Read more
impl SolValue for CancelOrderByOid
impl SolValue for CancelOrderByOid
type SolType = CancelOrderByOid
type SolType = CancelOrderByOid
The Solidity type that this type corresponds to.
fn tokenize(&self) -> <Self::SolType as SolType>::Token<'_>
fn tokenize(&self) -> <Self::SolType as SolType>::Token<'_>
Tokenizes the given value into this type’s token. Read more
fn detokenize(token: <Self::SolType as SolType>::Token<'_>) -> Selfwhere
Self: From<<Self::SolType as SolType>::RustType>,
fn detokenize(token: <Self::SolType as SolType>::Token<'_>) -> Selfwhere
Self: From<<Self::SolType as SolType>::RustType>,
Detokenize a value from the given token. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
Calculate the ABI-encoded size of the data. Read more
fn eip712_data_word(&self) -> FixedBytes<32>
fn eip712_data_word(&self) -> FixedBytes<32>
Encode this data according to EIP-712
encodeData rules, and hash it
if necessary. Read morefn abi_encode_packed_to(&self, out: &mut Vec<u8>)
fn abi_encode_packed_to(&self, out: &mut Vec<u8>)
Non-standard Packed Mode ABI encoding. Read more
fn abi_encode_sequence(&self) -> Vec<u8> ⓘwhere
<Self::SolType as SolType>::Token<'a>: for<'a> TokenSeq<'a>,
fn abi_encode_sequence(&self) -> Vec<u8> ⓘwhere
<Self::SolType as SolType>::Token<'a>: for<'a> TokenSeq<'a>,
Encodes an ABI sequence. Read more
fn abi_encode_params(&self) -> Vec<u8> ⓘwhere
<Self::SolType as SolType>::Token<'a>: for<'a> TokenSeq<'a>,
fn abi_encode_params(&self) -> Vec<u8> ⓘwhere
<Self::SolType as SolType>::Token<'a>: for<'a> TokenSeq<'a>,
Encodes an ABI sequence suitable for function parameters. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>where
Self: From<<Self::SolType as SolType>::RustType>,
fn abi_decode(data: &[u8]) -> Result<Self, Error>where
Self: From<<Self::SolType as SolType>::RustType>,
ABI-decode this type from the given data. Read more
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>where
Self: From<<Self::SolType as SolType>::RustType>,
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>where
Self: From<<Self::SolType as SolType>::RustType>,
ABI-decode this type from the given data, with validation. Read more
fn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self, Error>where
Self: From<<Self::SolType as SolType>::RustType>,
<Self::SolType as SolType>::Token<'de>: TokenSeq<'de>,
fn abi_decode_params<'de>(data: &'de [u8]) -> Result<Self, Error>where
Self: From<<Self::SolType as SolType>::RustType>,
<Self::SolType as SolType>::Token<'de>: TokenSeq<'de>,
ABI-decode this type from the given data. Read more
fn abi_decode_params_validate<'de>(data: &'de [u8]) -> Result<Self, Error>where
Self: From<<Self::SolType as SolType>::RustType>,
<Self::SolType as SolType>::Token<'de>: TokenSeq<'de>,
fn abi_decode_params_validate<'de>(data: &'de [u8]) -> Result<Self, Error>where
Self: From<<Self::SolType as SolType>::RustType>,
<Self::SolType as SolType>::Token<'de>: TokenSeq<'de>,
ABI-decode this type from the given data, with validation. Read more
impl Eq for CancelOrderByOid
impl StructuralPartialEq for CancelOrderByOid